@@ -170,7 +170,7 @@ sub ProcessAIFF($$)
         }
         $pos += $len2;
     }
-    $err and $exifTool->Warn('Error reading AIFF file -- corrupted?');
+    $err and $exifTool->Warn('Error reading AIFF file (corrupted?)');
     return 1;
 }
 
@@ -193,7 +193,7 @@ information from AIFF (Audio Interchange File Format) audio files.
 
 =head1 AUTHOR
 
-Copyright 2003-2007, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2008, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
